@@ -146,7 +146,6 @@
 #define BOTAN_HAS_CAST_128 20171203
 #define BOTAN_HAS_CERTSTOR_FLATFILE 20190410
 #define BOTAN_HAS_CERTSTOR_SQL 20160818
-#define BOTAN_HAS_CERTSTOR_SQLITE3 20160818
 #define BOTAN_HAS_CERTSTOR_SYSTEM 20190411
 #define BOTAN_HAS_CHACHA 20180807
 #define BOTAN_HAS_CHACHA_RNG 20170728
@@ -232,7 +231,6 @@
 #define BOTAN_HAS_KYBER_ROUND3 20240117
 #define BOTAN_HAS_LEGACY_EC_POINT 20250101
 #define BOTAN_HAS_LION 20131128
-#define BOTAN_HAS_LZMA 20160412
 #define BOTAN_HAS_MAC 20150626
 #define BOTAN_HAS_MCELIECE 20150922
 #define BOTAN_HAS_MD4 20131128
@@ -323,7 +321,6 @@
 #define BOTAN_HAS_TLS_13_PQC 20241208
 #define BOTAN_HAS_TLS_CBC 20161008
 #define BOTAN_HAS_TLS_SESSION_MANAGER_SQL_DB 20141219
-#define BOTAN_HAS_TLS_SQLITE3_SESSION_MANAGER 20131128
 #define BOTAN_HAS_TLS_V12_PRF 20131128
 #define BOTAN_HAS_TOTP 20180816
 #define BOTAN_HAS_TRUNCATED_HASH 20230215
@@ -423,7 +420,6 @@
 #define BOTAN_HAS_SM4_GFNI 20240803
 #define BOTAN_HAS_SM4_X86 20250311
 #define BOTAN_HAS_SOCKETS 20171216
-#define BOTAN_HAS_SQLITE3 20171118
 #define BOTAN_HAS_THREAD_UTILS 20190922
 #define BOTAN_HAS_UUID 20180930
 #define BOTAN_HAS_ZFEC_SSE2 20211211
